@@ -438,11 +438,13 @@ SMPlayer::ExitCode SMPlayer::processArgs(QStringList args) {
 	}
 #endif
 
+	/*
 	if (!pref->default_font.isEmpty()) {
 		QFont f;
 		f.fromString(pref->default_font);
 		qApp->setFont(f);
 	}
+	*/
 
 	return SMPlayer::NoExit;
 }
@@ -583,18 +585,18 @@ void SMPlayer::showInfo() {
 	qDebug("%s", s.toUtf8().data() );
 	qDebug("Compiled with Qt v. %s, using %s", QT_VERSION_STR, qVersion());
 
-	qDebug(" * application path: '%s'", Paths::appPath().toUtf8().data());
-	qDebug(" * data path: '%s'", Paths::dataPath().toUtf8().data());
-	qDebug(" * translation path: '%s'", Paths::translationPath().toUtf8().data());
-	qDebug(" * doc path: '%s'", Paths::docPath().toUtf8().data());
-	qDebug(" * themes path: '%s'", Paths::themesPath().toUtf8().data());
-	qDebug(" * shortcuts path: '%s'", Paths::shortcutsPath().toUtf8().data());
-	qDebug(" * config path: '%s'", Paths::configPath().toUtf8().data());
-	qDebug(" * ini path: '%s'", Paths::iniPath().toUtf8().data());
-	qDebug(" * file for subtitles' styles: '%s'", Paths::subtitleStyleFile().toUtf8().data());
-	qDebug(" * current path: '%s'", QDir::currentPath().toUtf8().data());
+	qDebug() << " * application path:" << Paths::appPath();
+	qDebug() << " * data path:" << Paths::dataPath();
+	qDebug() << " * translation path:" << Paths::translationPath();
+	qDebug() << " * doc path:" << Paths::docPath();
+	qDebug() << " * themes path:" << Paths::themesPath();
+	qDebug() << " * shortcuts path:" << Paths::shortcutsPath();
+	qDebug() << " * config path:" << Paths::configPath();
+	qDebug() << " * ini path:" << Paths::iniPath();
+	qDebug() << " * file for subtitles' styles:" << Paths::subtitleStyleFile();
+	qDebug() << " * current path:" << QDir::currentPath();
 #ifdef FONTS_HACK
-	qDebug(" * font path: '%s'", Paths::fontPath().toUtf8().data());
+	qDebug() << " * font path:" << Paths::fontPath();
 #endif
 }
 
@@ -658,6 +660,10 @@ void SMPlayer::myMessageOutput( QtMsgType type, const char *msg ) {
 			#endif
 			line2 = "CRITICAL: " + orig_line;
 			break;
+		#if QT_VERSION >= 0x050500
+		case QtInfoMsg:
+			break;
+		#endif
 	}
 
 	if (line2.isEmpty()) return;
